==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/nl/lang.php <==
<?php
/**
 * dutch language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author François Kooman <fkooman.tuxed.net>
 * @author Jack van Klaren <dokuwiki@afentoe.xs4all.nl>
 * @author Riny Heijdendael <riny@heijdendael.nl>
 * @author Koen Huybrechts <huybkoen@gmail.com>
 * @author Wouter Schoot <wouter@schoot.org>
 * @author John de Graaff <john@de-graaff.net>
 */
$lang['admin_acl']             = 'Toegangsrechten';
$lang['acl_group']             = 'Groep';
$lang['acl_user']              = 'Gebruiker';
$lang['acl_perms']             = 'Permissies voor';
$lang['page']                  = 'Pagina';
$lang['namespace']             = 'Namespace';
$lang['p_user_id']             = 'Gebruiker <b class="acluser">%s</b> heeft momenteel de volgende bevoegdheden op pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Gebruiker <b class="acluser">%s</b> heeft momenteel de volgende bevoegdheden op namespace <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Leden van groep <b class="aclgroup">%s</b> hebben momenteel de volgende bevoegdheden op pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Leden van groep <b class="aclgroup">%s</b>hebben momenteel de volgende bevoegdheden op namespace <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Vul een <b>gebruiker of groep</b> in middels het bovenstaande formaat om de bevoegdheden te bekijken of te bewerken voor de pagina <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Vul een <b>gebruiker of groep</b> in middels het bovenstaande formaat om de bevoegdheden te bekijken of te bewerken voor de namespace <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Let op: Deze permissies zijn niet expliciet ingesteld maar overge-ervd van andere groepen of hogere namespaces.';
$lang['p_isadmin']             = 'Let op: De geselecteerde groep of gebruiker heeft altijd volledige toegangsrechten omdat het als superuser geconfigureerd is.';
$lang['current']               = 'Huidige ACL regels';
$lang['where']                 = 'Pagina/namespace';
$lang['who']                   = 'Gebruiker/Groep';
$lang['perm']                  = 'Bevoegdheden';
$lang['acl_perm0']             = 'Geen';
$lang['acl_perm1']             = 'Lezen';
$lang['acl_perm2']             = 'Bewerken';
$lang['acl_perm4']             = 'Aanmaken';
$lang['acl_perm8']             = 'Upload';
$lang['acl_perm16']            = 'Verwijder';
$lang['acl_new']               = 'Nieuwe regel toevoegen';
$lang['acl_mod']               = 'Regel aanpassen';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/nl/lang.php <==
<?php
/**
 * dutch language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author François Kooman <fkooman.tuxed.net>
 * @author Jack van Klaren <dokuwiki@afentoe.xs4all.nl>
 * @author Riny Heijdendael <riny@heijdendael.nl>
 * @author Koen Huybrechts <huybkoen@gmail.com>
 * @author Wouter Schoot <wouter@schoot.org>
 * @author John de Graaff <john@de-graaff.net>
 * @author Niels Schoot <niels.schoot@quintiq.com>
 * @author Dion Nicolaas <dion@nicolaas.net>
 */
$lang['admin_acl']             = 'Toegangsrechten';
$lang['acl_group']             = 'Groep';
$lang['acl_user']              = 'Gebruiker';
$lang['acl_perms']             = 'Permissies voor';
$lang['page']                  = 'Pagina';
$lang['namespace']             = 'Namespace';
$lang['btn_select']            = 'Selecteer';
$lang['p_user_id']             = 'Gebruiker <b class="acluser">%s</b> heeft momenteel de volgende bevoegdheden op pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Gebruiker <b class="acluser">%s</b> heeft momenteel de volgende bevoegdheden op namespace <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Leden van groep <b class="aclgroup">%s</b> hebben momenteel de volgende bevoegdheden op pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Leden van groep <b class="aclgroup">%s</b>hebben momenteel de volgende bevoegdheden op namespace <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Vul een <b>gebruiker of groep</b> in in het bovenstaande formulier om de bevoegdheden te bekijken of te bewerken voor de pagina <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Vul een <b>gebruiker of groep</b> in in het bovenstaande formulier om de bevoegdheden te bekijken of te bewerken voor de namespace <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Let op: Deze permissies zijn niet expliciet ingesteld maar overerfd van andere groepen of hogere namespaces.';
$lang['p_isadmin']             = 'Let op: De geselecteerde groep of gebruiker heeft altijd volledige toegangsrechten omdat hij als superuser geconfigureerd is.';
$lang['p_include']             = 'Hogere permissies bevatten ook de lagere. Aanmaken, uploaden en verwijderen gelden alleen voor namespaces, niet voor pagina\'s.';
$lang['current']               = 'Huidige ACL regels';
$lang['where']                 = 'Pagina/namespace';
$lang['who']                   = 'Gebruiker/Groep';
$lang['perm']                  = 'Bevoegdheden';
$lang['acl_perm0']             = 'Geen';
$lang['acl_perm1']             = 'Lezen';
$lang['acl_perm2']             = 'Bewerken';
$lang['acl_perm4']             = 'Aanmaken';
$lang['acl_perm8']             = 'Uploaden';
$lang['acl_perm16']            = 'Verwijderen';
$lang['acl_new']               = 'Nieuwe regel toevoegen';
$lang['acl_mod']               = 'Regel aanpassen';
